# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, List, Union, Iterable, Optional
from typing_extensions import Literal, Required, Annotated, TypeAlias, TypedDict

from .._utils import PropertyInfo
from .chat_settings_param import ChatSettingsParam

__all__ = [
    "TaskCreateOrUpdateParams",
    "Main",
    "MainEvaluateStep",
    "MainToolCallStep",
    "MainPromptStepInput",
    "MainPromptStepInputPromptUnionMember0",
    "MainPromptStepInputPromptUnionMember0ContentUnionMember1",
    "MainPromptStepInputPromptUnionMember0ContentUnionMember1Content",
    "MainPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel",
    "MainPromptStepInputPromptUnionMember0ContentUnionMember1ContentModelImageURL",
    "MainPromptStepInputPromptUnionMember0ToolCall",
    "MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainPromptStepInputPromptUnionMember0ToolCallChosenBash20241022",
    "MainPromptStepInputToolChoice",
    "MainPromptStepInputToolChoiceNamedToolChoice",
    "MainPromptStepInputToolChoiceNamedToolChoiceFunction",
    "MainPromptStepInputToolsUnionMember1",
    "MainPromptStepInputToolsUnionMember1ToolRef",
    "MainPromptStepInputToolsUnionMember1ToolRefRef",
    "MainPromptStepInputToolsUnionMember1ToolRefRefToolRefByID",
    "MainPromptStepInputToolsUnionMember1ToolRefRefToolRefByName",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInput",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputAPICall",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputBash20241022",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputComputer20241022",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputFunction",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegration",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationDummyIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputSystem",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputTextEditor20241022",
    "MainGetStep",
    "MainSetStep",
    "MainLogStep",
    "MainYieldStep",
    "MainReturnStep",
    "MainSleepStep",
    "MainSleepStepSleep",
    "MainErrorWorkflowStep",
    "MainWaitForInputStep",
    "MainWaitForInputStepWaitForInput",
    "MainIfElseWorkflowStepInput",
    "MainIfElseWorkflowStepInputThen",
    "MainIfElseWorkflowStepInputThenEvaluateStep",
    "MainIfElseWorkflowStepInputThenToolCallStep",
    "MainIfElseWorkflowStepInputThenPromptStepInput",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1Content",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModelImageURL",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCall",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenBash20241022",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolChoice",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolChoiceNamedToolChoice",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolChoiceNamedToolChoiceFunction",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1ToolRef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1ToolRefRef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByID",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByName",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInput",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputAPICall",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputBash20241022",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputComputer20241022",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputFunction",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegration",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationDummyIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputSystem",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputTextEditor20241022",
    "MainIfElseWorkflowStepInputThenGetStep",
    "MainIfElseWorkflowStepInputThenSetStep",
    "MainIfElseWorkflowStepInputThenLogStep",
    "MainIfElseWorkflowStepInputThenYieldStep",
    "MainIfElseWorkflowStepInputThenReturnStep",
    "MainIfElseWorkflowStepInputThenSleepStep",
    "MainIfElseWorkflowStepInputThenSleepStepSleep",
    "MainIfElseWorkflowStepInputThenErrorWorkflowStep",
    "MainIfElseWorkflowStepInputThenWaitForInputStep",
    "MainIfElseWorkflowStepInputThenWaitForInputStepWaitForInput",
    "MainIfElseWorkflowStepInputElse",
    "MainIfElseWorkflowStepInputElseEvaluateStep",
    "MainIfElseWorkflowStepInputElseToolCallStep",
    "MainIfElseWorkflowStepInputElsePromptStepInput",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1Content",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1ContentModel",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1ContentModelImageURL",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCall",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenBash20241022",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolChoice",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolChoiceNamedToolChoice",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolChoiceNamedToolChoiceFunction",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1ToolRef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1ToolRefRef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1ToolRefRefToolRefByID",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1ToolRefRefToolRefByName",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInput",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputAPICall",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputBash20241022",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputComputer20241022",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputFunction",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegration",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationDummyIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputSystem",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputTextEditor20241022",
    "MainIfElseWorkflowStepInputElseGetStep",
    "MainIfElseWorkflowStepInputElseSetStep",
    "MainIfElseWorkflowStepInputElseLogStep",
    "MainIfElseWorkflowStepInputElseYieldStep",
    "MainIfElseWorkflowStepInputElseReturnStep",
    "MainIfElseWorkflowStepInputElseSleepStep",
    "MainIfElseWorkflowStepInputElseSleepStepSleep",
    "MainIfElseWorkflowStepInputElseErrorWorkflowStep",
    "MainIfElseWorkflowStepInputElseWaitForInputStep",
    "MainIfElseWorkflowStepInputElseWaitForInputStepWaitForInput",
    "MainSwitchStepInput",
    "MainSwitchStepInputSwitch",
    "MainSwitchStepInputSwitchThen",
    "MainSwitchStepInputSwitchThenEvaluateStep",
    "MainSwitchStepInputSwitchThenToolCallStep",
    "MainSwitchStepInputSwitchThenPromptStepInput",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1Content",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModelImageURL",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCall",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenBash20241022",
    "MainSwitchStepInputSwitchThenPromptStepInputToolChoice",
    "MainSwitchStepInputSwitchThenPromptStepInputToolChoiceNamedToolChoice",
    "MainSwitchStepInputSwitchThenPromptStepInputToolChoiceNamedToolChoiceFunction",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByID",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByName",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInput",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputAPICall",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputBash20241022",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputComputer20241022",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputFunction",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegration",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationDummyIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputSystem",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputTextEditor20241022",
    "MainSwitchStepInputSwitchThenGetStep",
    "MainSwitchStepInputSwitchThenSetStep",
    "MainSwitchStepInputSwitchThenLogStep",
    "MainSwitchStepInputSwitchThenYieldStep",
    "MainSwitchStepInputSwitchThenReturnStep",
    "MainSwitchStepInputSwitchThenSleepStep",
    "MainSwitchStepInputSwitchThenSleepStepSleep",
    "MainSwitchStepInputSwitchThenErrorWorkflowStep",
    "MainSwitchStepInputSwitchThenWaitForInputStep",
    "MainSwitchStepInputSwitchThenWaitForInputStepWaitForInput",
    "MainForeachStepInput",
    "MainForeachStepInputForeach",
    "MainForeachStepInputForeachDo",
    "MainForeachStepInputForeachDoWaitForInputStep",
    "MainForeachStepInputForeachDoWaitForInputStepWaitForInput",
    "MainForeachStepInputForeachDoEvaluateStep",
    "MainForeachStepInputForeachDoToolCallStep",
    "MainForeachStepInputForeachDoPromptStepInput",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1Content",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModelImageURL",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCall",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenBash20241022",
    "MainForeachStepInputForeachDoPromptStepInputToolChoice",
    "MainForeachStepInputForeachDoPromptStepInputToolChoiceNamedToolChoice",
    "MainForeachStepInputForeachDoPromptStepInputToolChoiceNamedToolChoiceFunction",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRefToolRefByID",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRefToolRefByName",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInput",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputAPICall",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputBash20241022",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputComputer20241022",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputFunction",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegration",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationDummyIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputSystem",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputTextEditor20241022",
    "MainForeachStepInputForeachDoGetStep",
    "MainForeachStepInputForeachDoSetStep",
    "MainForeachStepInputForeachDoLogStep",
    "MainForeachStepInputForeachDoYieldStep",
    "MainParallelStepInput",
    "MainParallelStepInputParallel",
    "MainParallelStepInputParallelEvaluateStep",
    "MainParallelStepInputParallelToolCallStep",
    "MainParallelStepInputParallelPromptStepInput",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1Content",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModelImageURL",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCall",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenBash20241022",
    "MainParallelStepInputParallelPromptStepInputToolChoice",
    "MainParallelStepInputParallelPromptStepInputToolChoiceNamedToolChoice",
    "MainParallelStepInputParallelPromptStepInputToolChoiceNamedToolChoiceFunction",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRefToolRefByID",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRefToolRefByName",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInput",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputAPICall",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputBash20241022",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputComputer20241022",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputFunction",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegration",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationDummyIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputSystem",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputTextEditor20241022",
    "MainParallelStepInputParallelGetStep",
    "MainParallelStepInputParallelSetStep",
    "MainParallelStepInputParallelLogStep",
    "MainParallelStepInputParallelYieldStep",
    "MainMainInput",
    "MainMainInputMap",
    "MainMainInputMapEvaluateStep",
    "MainMainInputMapToolCallStep",
    "MainMainInputMapPromptStepInput",
    "MainMainInputMapPromptStepInputPromptUnionMember0",
    "MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1",
    "MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1Content",
    "MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel",
    "MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModelImageURL",
    "MainMainInputMapPromptStepInputPromptUnionMember0ToolCall",
    "MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenBash20241022",
    "MainMainInputMapPromptStepInputToolChoice",
    "MainMainInputMapPromptStepInputToolChoiceNamedToolChoice",
    "MainMainInputMapPromptStepInputToolChoiceNamedToolChoiceFunction",
    "MainMainInputMapPromptStepInputToolsUnionMember1",
    "MainMainInputMapPromptStepInputToolsUnionMember1ToolRef",
    "MainMainInputMapPromptStepInputToolsUnionMember1ToolRefRef",
    "MainMainInputMapPromptStepInputToolsUnionMember1ToolRefRefToolRefByID",
    "MainMainInputMapPromptStepInputToolsUnionMember1ToolRefRefToolRefByName",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInput",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputAPICall",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputBash20241022",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputComputer20241022",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputFunction",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegration",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationDummyIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputSystem",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputTextEditor20241022",
    "MainMainInputMapGetStep",
    "MainMainInputMapSetStep",
    "MainMainInputMapLogStep",
    "MainMainInputMapYieldStep",
    "Tool",
    "ToolAPICall",
    "ToolBash20241022",
    "ToolComputer20241022",
    "ToolFunction",
    "ToolIntegration",
    "ToolIntegrationDummyIntegrationDef",
    "ToolIntegrationBraveIntegrationDef",
    "ToolIntegrationBraveIntegrationDefArguments",
    "ToolIntegrationBraveIntegrationDefSetup",
    "ToolIntegrationEmailIntegrationDef",
    "ToolIntegrationEmailIntegrationDefArguments",
    "ToolIntegrationEmailIntegrationDefSetup",
    "ToolIntegrationSpiderIntegrationDef",
    "ToolIntegrationSpiderIntegrationDefArguments",
    "ToolIntegrationSpiderIntegrationDefSetup",
    "ToolIntegrationWikipediaIntegrationDef",
    "ToolIntegrationWikipediaIntegrationDefArguments",
    "ToolIntegrationWeatherIntegrationDef",
    "ToolIntegrationWeatherIntegrationDefArguments",
    "ToolIntegrationWeatherIntegrationDefSetup",
    "ToolIntegrationBrowserbaseContextIntegrationDef",
    "ToolIntegrationBrowserbaseContextIntegrationDefArguments",
    "ToolIntegrationBrowserbaseContextIntegrationDefSetup",
    "ToolIntegrationBrowserbaseExtensionIntegrationDef",
    "ToolIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "ToolIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "ToolIntegrationBrowserbaseListSessionsIntegrationDef",
    "ToolIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "ToolIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "ToolIntegrationBrowserbaseCreateSessionIntegrationDef",
    "ToolIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "ToolIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "ToolIntegrationBrowserbaseGetSessionIntegrationDef",
    "ToolIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "ToolIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "ToolIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "ToolIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "ToolIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "ToolIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "ToolIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "ToolIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "ToolIntegrationBrowserbaseGetSessionConnectURLIntegrationDef",
    "ToolIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments",
    "ToolIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup",
    "ToolIntegrationRemoteBrowserIntegrationDef",
    "ToolIntegrationRemoteBrowserIntegrationDefSetup",
    "ToolIntegrationRemoteBrowserIntegrationDefArguments",
    "ToolSystem",
    "ToolTextEditor20241022",
]


class TaskCreateOrUpdateParams(TypedDict, total=False):
    agent_id: Required[str]

    main: Required[Iterable[Main]]

    name: Required[str]

    description: str

    inherit_tools: bool

    input_schema: Optional[object]

    metadata: Optional[object]

    tools: Iterable[Tool]


class MainEvaluateStep(TypedDict, total=False):
    evaluate: Required[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]]

    label: Optional[str]


class MainToolCallStep(TypedDict, total=False):
    tool: Required[str]

    arguments: Union[
        Dict[
            str,
            Union[
                Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
                Iterable[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]],
                str,
            ],
        ],
        Iterable[
            Dict[
                str,
                Union[
                    Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
                    Iterable[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]],
                    str,
                ],
            ]
        ],
        Literal["_"],
    ]

    label: Optional[str]


class MainPromptStepInputPromptUnionMember0ContentUnionMember1Content(TypedDict, total=False):
    text: Required[str]

    type: Literal["text"]


class MainPromptStepInputPromptUnionMember0ContentUnionMember1ContentModelImageURL(TypedDict, total=False):
    url: Required[str]

    detail: Literal["low", "high", "auto"]


class MainPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel(TypedDict, total=False):
    image_url: Required[MainPromptStepInputPromptUnionMember0ContentUnionMember1ContentModelImageURL]
    """The image URL"""

    type: Literal["image_url"]


MainPromptStepInputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainPromptStepInputPromptUnionMember0ContentUnionMember1Content,
    MainPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel,
]


class MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction(TypedDict, total=False):
    name: Required[str]

    arguments: Optional[str]


class MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(TypedDict, total=False):
    command: Optional[str]

    restart: bool


class MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(TypedDict, total=False):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(TypedDict, total=False):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall(TypedDict, total=False):
    function: Required[MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction]

    api_call: Optional[object]

    bash_20241022: Optional[MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022]

    computer_20241022: Optional[MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022]

    integration: Optional[object]

    system: Optional[object]

    text_editor_20241022: Optional[MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022]

    type: Literal["function"]


class MainPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022(TypedDict, total=False):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022(TypedDict, total=False):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainPromptStepInputPromptUnionMember0ToolCallChosenBash20241022(TypedDict, total=False):
    command: Optional[str]

    restart: bool


MainPromptStepInputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall,
    MainPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022,
    MainPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainPromptStepInputPromptUnionMember0ToolCallChosenBash20241022,
]

_MainPromptStepInputPromptUnionMember0ReservedKeywords = TypedDict(
    "_MainPromptStepInputPromptUnionMember0ReservedKeywords",
    {
        "continue": Optional[bool],
    },
    total=False,
)


class MainPromptStepInputPromptUnionMember0(_MainPromptStepInputPromptUnionMember0ReservedKeywords, total=False):
    content: Required[Union[List[str], Iterable[MainPromptStepInputPromptUnionMember0ContentUnionMember1], str, None]]

    role: Required[Literal["user", "assistant", "system", "tool"]]

    name: Optional[str]

    tool_call_id: Optional[str]

    tool_calls: Optional[Iterable[MainPromptStepInputPromptUnionMember0ToolCall]]


class MainPromptStepInputToolChoiceNamedToolChoiceFunction(TypedDict, total=False):
    name: Required[str]

    arguments: Optional[str]


class MainPromptStepInputToolChoiceNamedToolChoice(TypedDict, total=False):
    function: Optional[MainPromptStepInputToolChoiceNamedToolChoiceFunction]


MainPromptStepInputToolChoice: TypeAlias = Union[Literal["auto", "none"], MainPromptStepInputToolChoiceNamedToolChoice]


class MainPromptStepInputToolsUnionMember1ToolRefRefToolRefByID(TypedDict, total=False):
    id: Optional[str]


class MainPromptStepInputToolsUnionMember1ToolRefRefToolRefByName(TypedDict, total=False):
    name: Optional[str]


MainPromptStepInputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainPromptStepInputToolsUnionMember1ToolRefRefToolRefByID,
    MainPromptStepInputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainPromptStepInputToolsUnionMember1ToolRef(TypedDict, total=False):
    ref: Required[MainPromptStepInputToolsUnionMember1ToolRefRef]
    """Reference to a tool by id"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputAPICall(
    TypedDict, total=False
):
    method: Required[Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]]

    url: Required[str]

    content: Optional[str]

    cookies: Optional[Dict[str, str]]

    data: Optional[object]

    follow_redirects: Optional[bool]

    headers: Optional[Dict[str, str]]

    json: Optional[object]

    params: Union[str, object, None]

    schema: Optional[object]

    timeout: Optional[int]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputBash20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["bash_20241022"]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputComputer20241022(
    TypedDict, total=False
):
    display_height_px: int

    display_number: int

    display_width_px: int

    name: str

    type: Literal["computer_20241022"]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputFunction(
    TypedDict, total=False
):
    description: Optional[object]

    name: Optional[object]

    parameters: Optional[object]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationDummyIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[object]

    method: Optional[str]

    provider: Literal["dummy"]

    setup: Optional[object]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefArguments
    ]
    """Arguments for Brave Search"""

    method: Optional[str]

    provider: Literal["brave"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefSetup
    ]
    """Integration definition for Brave Search"""


_MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArguments(
    _MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefSetup(
    TypedDict, total=False
):
    host: Required[str]

    password: Required[str]

    port: Required[int]

    user: Required[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArguments
    ]
    """Arguments for Email sending"""

    method: Optional[str]

    provider: Literal["email"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefSetup
    ]
    """Setup parameters for Email integration"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefArguments(
    TypedDict, total=False
):
    url: Required[str]

    mode: Literal["scrape"]

    params: Optional[object]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefSetup(
    TypedDict, total=False
):
    spider_api_key: Required[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefArguments
    ]
    """Arguments for Spider integration"""

    method: Optional[str]

    provider: Literal["spider"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefSetup
    ]
    """Setup parameters for Spider integration"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    load_max_docs: int


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments
    ]
    """Arguments for Wikipedia Search"""

    method: Optional[str]

    provider: Literal["wikipedia"]

    setup: Optional[object]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefArguments(
    TypedDict, total=False
):
    location: Required[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefSetup(
    TypedDict, total=False
):
    openweathermap_api_key: Required[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefArguments
    ]
    """Arguments for Weather"""

    method: Optional[str]

    provider: Literal["weather"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefSetup
    ]
    """Integration definition for Weather"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments(
    TypedDict, total=False
):
    project_id: Required[Annotated[str, PropertyInfo(alias="projectId")]]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments
    ]

    method: Literal["create_context"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    TypedDict, total=False
):
    repository_name: Required[Annotated[str, PropertyInfo(alias="repositoryName")]]

    ref: Optional[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ]

    method: Optional[Literal["install_extension_from_github"]]

    provider: Literal["browserbase"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    TypedDict, total=False
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ]

    method: Literal["list_sessions"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    TypedDict, total=False
):
    browser_settings: Annotated[object, PropertyInfo(alias="browserSettings")]

    extension_id: Annotated[Optional[str], PropertyInfo(alias="extensionId")]

    keep_alive: Annotated[bool, PropertyInfo(alias="keepAlive")]

    project_id: Annotated[Optional[str], PropertyInfo(alias="projectId")]

    proxies: Union[bool, Iterable[object]]

    timeout: int


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ]

    method: Literal["create_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ]

    method: Literal["get_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]

    status: Literal["REQUEST_RELEASE"]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ]

    method: Literal["complete_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ]

    method: Literal["get_live_urls"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments
    ]

    method: Literal["get_connect_url"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup(
    TypedDict, total=False
):
    connect_url: Optional[str]

    height: Optional[int]

    width: Optional[int]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "mouse_move",
            "left_click",
            "left_click_drag",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
            "cursor_position",
            "navigate",
            "refresh",
        ]
    ]

    connect_url: Optional[str]

    coordinate: Optional[Iterable[object]]

    text: Optional[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef(
    TypedDict, total=False
):
    setup: Required[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup
    ]
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments
    ]
    """The arguments for the remote browser"""

    method: Literal["perform_action"]

    provider: Literal["remote_browser"]


MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegration: TypeAlias = Union[
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationDummyIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef,
]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputSystem(
    TypedDict, total=False
):
    operation: Required[
        Literal[
            "create",
            "update",
            "patch",
            "create_or_update",
            "embed",
            "change_status",
            "search",
            "chat",
            "history",
            "delete",
            "get",
            "list",
        ]
    ]

    resource: Required[Literal["agent", "user", "task", "execution", "doc", "session", "job"]]

    arguments: Optional[object]

    resource_id: Optional[str]

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputTextEditor20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["text_editor_20241022"]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInput(TypedDict, total=False):
    name: Required[str]

    type: Required[
        Literal[
            "function",
            "integration",
            "system",
            "api_call",
            "computer_20241022",
            "text_editor_20241022",
            "bash_20241022",
        ]
    ]

    api_call: Optional[MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputAPICall]
    """API call definition"""

    bash_20241022: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputBash20241022
    ]

    computer_20241022: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputComputer20241022
    ]
    """Anthropic new tools"""

    description: Optional[str]

    function: Optional[MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputFunction]
    """Function definition"""

    integration: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegration
    ]
    """Brave integration definition"""

    system: Optional[MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputSystem]
    """System definition"""

    text_editor_20241022: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputTextEditor20241022
    ]


MainPromptStepInputToolsUnionMember1: TypeAlias = Union[
    MainPromptStepInputToolsUnionMember1ToolRef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInput,
]


class MainPromptStepInput(TypedDict, total=False):
    prompt: Required[Union[Iterable[MainPromptStepInputPromptUnionMember0], str]]

    auto_run_tools: bool

    disable_cache: bool

    label: Optional[str]

    settings: Optional[ChatSettingsParam]

    tool_choice: Optional[MainPromptStepInputToolChoice]

    tools: Union[Literal["all"], Iterable[MainPromptStepInputToolsUnionMember1]]

    unwrap: bool


class MainGetStep(TypedDict, total=False):
    get: Required[str]

    label: Optional[str]


class MainSetStep(TypedDict, total=False):
    set: Required[Dict[str, str]]

    label: Optional[str]


class MainLogStep(TypedDict, total=False):
    log: Required[str]

    label: Optional[str]


class MainYieldStep(TypedDict, total=False):
    workflow: Required[str]

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]], Literal["_"]]

    label: Optional[str]


_MainReturnStepReservedKeywords = TypedDict(
    "_MainReturnStepReservedKeywords",
    {
        "return": Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
    },
    total=False,
)


class MainReturnStep(_MainReturnStepReservedKeywords, total=False):
    label: Optional[str]


class MainSleepStepSleep(TypedDict, total=False):
    days: int

    hours: int

    minutes: int

    seconds: int


class MainSleepStep(TypedDict, total=False):
    sleep: Required[MainSleepStepSleep]

    label: Optional[str]


class MainErrorWorkflowStep(TypedDict, total=False):
    error: Required[str]

    label: Optional[str]


class MainWaitForInputStepWaitForInput(TypedDict, total=False):
    info: Required[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]]


class MainWaitForInputStep(TypedDict, total=False):
    wait_for_input: Required[MainWaitForInputStepWaitForInput]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenEvaluateStep(TypedDict, total=False):
    evaluate: Required[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenToolCallStep(TypedDict, total=False):
    tool: Required[str]

    arguments: Union[
        Dict[
            str,
            Union[
                Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
                Iterable[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]],
                str,
            ],
        ],
        Iterable[
            Dict[
                str,
                Union[
                    Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
                    Iterable[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]],
                    str,
                ],
            ]
        ],
        Literal["_"],
    ]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1Content(
    TypedDict, total=False
):
    text: Required[str]

    type: Literal["text"]


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModelImageURL(
    TypedDict, total=False
):
    url: Required[str]

    detail: Literal["low", "high", "auto"]


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel(
    TypedDict, total=False
):
    image_url: Required[
        MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModelImageURL
    ]
    """The image URL"""

    type: Literal["image_url"]


MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1Content,
    MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel,
]


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction(
    TypedDict, total=False
):
    name: Required[str]

    arguments: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(
    TypedDict, total=False
):
    command: Optional[str]

    restart: bool


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall(
    TypedDict, total=False
):
    function: Required[
        MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction
    ]

    api_call: Optional[object]

    bash_20241022: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022
    ]

    computer_20241022: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ]

    integration: Optional[object]

    system: Optional[object]

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ]

    type: Literal["function"]


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenBash20241022(
    TypedDict, total=False
):
    command: Optional[str]

    restart: bool


MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall,
    MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022,
    MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenBash20241022,
]

_MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ReservedKeywords",
    {
        "continue": Optional[bool],
    },
    total=False,
)


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0(
    _MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ReservedKeywords, total=False
):
    content: Required[
        Union[
            List[str],
            Iterable[MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1],
            str,
            None,
        ]
    ]

    role: Required[Literal["user", "assistant", "system", "tool"]]

    name: Optional[str]

    tool_call_id: Optional[str]

    tool_calls: Optional[Iterable[MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCall]]


class MainIfElseWorkflowStepInputThenPromptStepInputToolChoiceNamedToolChoiceFunction(TypedDict, total=False):
    name: Required[str]

    arguments: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolChoiceNamedToolChoice(TypedDict, total=False):
    function: Optional[MainIfElseWorkflowStepInputThenPromptStepInputToolChoiceNamedToolChoiceFunction]


MainIfElseWorkflowStepInputThenPromptStepInputToolChoice: TypeAlias = Union[
    Literal["auto", "none"], MainIfElseWorkflowStepInputThenPromptStepInputToolChoiceNamedToolChoice
]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByID(TypedDict, total=False):
    id: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByName(TypedDict, total=False):
    name: Optional[str]


MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByID,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1ToolRef(TypedDict, total=False):
    ref: Required[MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1ToolRefRef]
    """Reference to a tool by id"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputAPICall(
    TypedDict, total=False
):
    method: Required[Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]]

    url: Required[str]

    content: Optional[str]

    cookies: Optional[Dict[str, str]]

    data: Optional[object]

    follow_redirects: Optional[bool]

    headers: Optional[Dict[str, str]]

    json: Optional[object]

    params: Union[str, object, None]

    schema: Optional[object]

    timeout: Optional[int]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputBash20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["bash_20241022"]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputComputer20241022(
    TypedDict, total=False
):
    display_height_px: int

    display_number: int

    display_width_px: int

    name: str

    type: Literal["computer_20241022"]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputFunction(
    TypedDict, total=False
):
    description: Optional[object]

    name: Optional[object]

    parameters: Optional[object]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationDummyIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[object]

    method: Optional[str]

    provider: Literal["dummy"]

    setup: Optional[object]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefArguments
    ]
    """Arguments for Brave Search"""

    method: Optional[str]

    provider: Literal["brave"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefSetup
    ]
    """Integration definition for Brave Search"""


_MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArguments(
    _MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefSetup(
    TypedDict, total=False
):
    host: Required[str]

    password: Required[str]

    port: Required[int]

    user: Required[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArguments
    ]
    """Arguments for Email sending"""

    method: Optional[str]

    provider: Literal["email"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefSetup
    ]
    """Setup parameters for Email integration"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefArguments(
    TypedDict, total=False
):
    url: Required[str]

    mode: Literal["scrape"]

    params: Optional[object]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefSetup(
    TypedDict, total=False
):
    spider_api_key: Required[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefArguments
    ]
    """Arguments for Spider integration"""

    method: Optional[str]

    provider: Literal["spider"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefSetup
    ]
    """Setup parameters for Spider integration"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    load_max_docs: int


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments
    ]
    """Arguments for Wikipedia Search"""

    method: Optional[str]

    provider: Literal["wikipedia"]

    setup: Optional[object]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefArguments(
    TypedDict, total=False
):
    location: Required[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefSetup(
    TypedDict, total=False
):
    openweathermap_api_key: Required[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefArguments
    ]
    """Arguments for Weather"""

    method: Optional[str]

    provider: Literal["weather"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefSetup
    ]
    """Integration definition for Weather"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments(
    TypedDict, total=False
):
    project_id: Required[Annotated[str, PropertyInfo(alias="projectId")]]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments
    ]

    method: Literal["create_context"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    TypedDict, total=False
):
    repository_name: Required[Annotated[str, PropertyInfo(alias="repositoryName")]]

    ref: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ]

    method: Optional[Literal["install_extension_from_github"]]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    TypedDict, total=False
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ]

    method: Literal["list_sessions"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    TypedDict, total=False
):
    browser_settings: Annotated[object, PropertyInfo(alias="browserSettings")]

    extension_id: Annotated[Optional[str], PropertyInfo(alias="extensionId")]

    keep_alive: Annotated[bool, PropertyInfo(alias="keepAlive")]

    project_id: Annotated[Optional[str], PropertyInfo(alias="projectId")]

    proxies: Union[bool, Iterable[object]]

    timeout: int


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ]

    method: Literal["create_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ]

    method: Literal["get_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]

    status: Literal["REQUEST_RELEASE"]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ]

    method: Literal["complete_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ]

    method: Literal["get_live_urls"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments
    ]

    method: Literal["get_connect_url"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup(
    TypedDict, total=False
):
    connect_url: Optional[str]

    height: Optional[int]

    width: Optional[int]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "mouse_move",
            "left_click",
            "left_click_drag",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
            "cursor_position",
            "navigate",
            "refresh",
        ]
    ]

    connect_url: Optional[str]

    coordinate: Optional[Iterable[object]]

    text: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef(
    TypedDict, total=False
):
    setup: Required[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup
    ]
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments
    ]
    """The arguments for the remote browser"""

    method: Literal["perform_action"]

    provider: Literal["remote_browser"]


MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegration: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationDummyIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef,
]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputSystem(
    TypedDict, total=False
):
    operation: Required[
        Literal[
            "create",
            "update",
            "patch",
            "create_or_update",
            "embed",
            "change_status",
            "search",
            "chat",
            "history",
            "delete",
            "get",
            "list",
        ]
    ]

    resource: Required[Literal["agent", "user", "task", "execution", "doc", "session", "job"]]

    arguments: Optional[object]

    resource_id: Optional[str]

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputTextEditor20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["text_editor_20241022"]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInput(
    TypedDict, total=False
):
    name: Required[str]

    type: Required[
        Literal[
            "function",
            "integration",
            "system",
            "api_call",
            "computer_20241022",
            "text_editor_20241022",
            "bash_20241022",
        ]
    ]

    api_call: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputAPICall
    ]
    """API call definition"""

    bash_20241022: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputBash20241022
    ]

    computer_20241022: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputComputer20241022
    ]
    """Anthropic new tools"""

    description: Optional[str]

    function: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputFunction
    ]
    """Function definition"""

    integration: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegration
    ]
    """Brave integration definition"""

    system: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputSystem
    ]
    """System definition"""

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputTextEditor20241022
    ]


MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1ToolRef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInput,
]


class MainIfElseWorkflowStepInputThenPromptStepInput(TypedDict, total=False):
    prompt: Required[Union[Iterable[MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0], str]]

    auto_run_tools: bool

    disable_cache: bool

    label: Optional[str]

    settings: Optional[ChatSettingsParam]

    tool_choice: Optional[MainIfElseWorkflowStepInputThenPromptStepInputToolChoice]

    tools: Union[Literal["all"], Iterable[MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1]]

    unwrap: bool


class MainIfElseWorkflowStepInputThenGetStep(TypedDict, total=False):
    get: Required[str]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenSetStep(TypedDict, total=False):
    set: Required[Dict[str, str]]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenLogStep(TypedDict, total=False):
    log: Required[str]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenYieldStep(TypedDict, total=False):
    workflow: Required[str]

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]], Literal["_"]]

    label: Optional[str]


_MainIfElseWorkflowStepInputThenReturnStepReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputThenReturnStepReservedKeywords",
    {
        "return": Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
    },
    total=False,
)


class MainIfElseWorkflowStepInputThenReturnStep(
    _MainIfElseWorkflowStepInputThenReturnStepReservedKeywords, total=False
):
    label: Optional[str]


class MainIfElseWorkflowStepInputThenSleepStepSleep(TypedDict, total=False):
    days: int

    hours: int

    minutes: int

    seconds: int


class MainIfElseWorkflowStepInputThenSleepStep(TypedDict, total=False):
    sleep: Required[MainIfElseWorkflowStepInputThenSleepStepSleep]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenErrorWorkflowStep(TypedDict, total=False):
    error: Required[str]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenWaitForInputStepWaitForInput(TypedDict, total=False):
    info: Required[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]]


class MainIfElseWorkflowStepInputThenWaitForInputStep(TypedDict, total=False):
    wait_for_input: Required[MainIfElseWorkflowStepInputThenWaitForInputStepWaitForInput]

    label: Optional[str]


MainIfElseWorkflowStepInputThen: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenEvaluateStep,
    MainIfElseWorkflowStepInputThenToolCallStep,
    MainIfElseWorkflowStepInputThenPromptStepInput,
    MainIfElseWorkflowStepInputThenGetStep,
    MainIfElseWorkflowStepInputThenSetStep,
    MainIfElseWorkflowStepInputThenLogStep,
    MainIfElseWorkflowStepInputThenYieldStep,
    MainIfElseWorkflowStepInputThenReturnStep,
    MainIfElseWorkflowStepInputThenSleepStep,
    MainIfElseWorkflowStepInputThenErrorWorkflowStep,
    MainIfElseWorkflowStepInputThenWaitForInputStep,
]


class MainIfElseWorkflowStepInputElseEvaluateStep(TypedDict, total=False):
    evaluate: Required[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseToolCallStep(TypedDict, total=False):
    tool: Required[str]

    arguments: Union[
        Dict[
            str,
            Union[
                Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
                Iterable[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]],
                str,
            ],
        ],
        Iterable[
            Dict[
                str,
                Union[
                    Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
                    Iterable[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]],
                    str,
                ],
            ]
        ],
        Literal["_"],
    ]

    label: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1Content(
    TypedDict, total=False
):
    text: Required[str]

    type: Literal["text"]


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1ContentModelImageURL(
    TypedDict, total=False
):
    url: Required[str]

    detail: Literal["low", "high", "auto"]


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1ContentModel(
    TypedDict, total=False
):
    image_url: Required[
        MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1ContentModelImageURL
    ]
    """The image URL"""

    type: Literal["image_url"]


MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1Content,
    MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1ContentModel,
]


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction(
    TypedDict, total=False
):
    name: Required[str]

    arguments: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(
    TypedDict, total=False
):
    command: Optional[str]

    restart: bool


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCall(
    TypedDict, total=False
):
    function: Required[
        MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction
    ]

    api_call: Optional[object]

    bash_20241022: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022
    ]

    computer_20241022: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ]

    integration: Optional[object]

    system: Optional[object]

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ]

    type: Literal["function"]


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenBash20241022(
    TypedDict, total=False
):
    command: Optional[str]

    restart: bool


MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCall,
    MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenComputer20241022,
    MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenBash20241022,
]

_MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ReservedKeywords",
    {
        "continue": Optional[bool],
    },
    total=False,
)


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0(
    _MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ReservedKeywords, total=False
):
    content: Required[
        Union[
            List[str],
            Iterable[MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1],
            str,
            None,
        ]
    ]

    role: Required[Literal["user", "assistant", "system", "tool"]]

    name: Optional[str]

    tool_call_id: Optional[str]

    tool_calls: Optional[Iterable[MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCall]]


class MainIfElseWorkflowStepInputElsePromptStepInputToolChoiceNamedToolChoiceFunction(TypedDict, total=False):
    name: Required[str]

    arguments: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolChoiceNamedToolChoice(TypedDict, total=False):
    function: Optional[MainIfElseWorkflowStepInputElsePromptStepInputToolChoiceNamedToolChoiceFunction]


MainIfElseWorkflowStepInputElsePromptStepInputToolChoice: TypeAlias = Union[
    Literal["auto", "none"], MainIfElseWorkflowStepInputElsePromptStepInputToolChoiceNamedToolChoice
]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1ToolRefRefToolRefByID(TypedDict, total=False):
    id: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1ToolRefRefToolRefByName(TypedDict, total=False):
    name: Optional[str]


MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1ToolRefRefToolRefByID,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1ToolRef(TypedDict, total=False):
    ref: Required[MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1ToolRefRef]
    """Reference to a tool by id"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputAPICall(
    TypedDict, total=False
):
    method: Required[Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]]

    url: Required[str]

    content: Optional[str]

    cookies: Optional[Dict[str, str]]

    data: Optional[object]

    follow_redirects: Optional[bool]

    headers: Optional[Dict[str, str]]

    json: Optional[object]

    params: Union[str, object, None]

    schema: Optional[object]

    timeout: Optional[int]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputBash20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["bash_20241022"]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputComputer20241022(
    TypedDict, total=False
):
    display_height_px: int

    display_number: int

    display_width_px: int

    name: str

    type: Literal["computer_20241022"]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputFunction(
    TypedDict, total=False
):
    description: Optional[object]

    name: Optional[object]

    parameters: Optional[object]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationDummyIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[object]

    method: Optional[str]

    provider: Literal["dummy"]

    setup: Optional[object]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefArguments
    ]
    """Arguments for Brave Search"""

    method: Optional[str]

    provider: Literal["brave"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefSetup
    ]
    """Integration definition for Brave Search"""


_MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArguments(
    _MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefSetup(
    TypedDict, total=False
):
    host: Required[str]

    password: Required[str]

    port: Required[int]

    user: Required[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArguments
    ]
    """Arguments for Email sending"""

    method: Optional[str]

    provider: Literal["email"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefSetup
    ]
    """Setup parameters for Email integration"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefArguments(
    TypedDict, total=False
):
    url: Required[str]

    mode: Literal["scrape"]

    params: Optional[object]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefSetup(
    TypedDict, total=False
):
    spider_api_key: Required[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefArguments
    ]
    """Arguments for Spider integration"""

    method: Optional[str]

    provider: Literal["spider"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefSetup
    ]
    """Setup parameters for Spider integration"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    load_max_docs: int


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments
    ]
    """Arguments for Wikipedia Search"""

    method: Optional[str]

    provider: Literal["wikipedia"]

    setup: Optional[object]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefArguments(
    TypedDict, total=False
):
    location: Required[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefSetup(
    TypedDict, total=False
):
    openweathermap_api_key: Required[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefArguments
    ]
    """Arguments for Weather"""

    method: Optional[str]

    provider: Literal["weather"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefSetup
    ]
    """Integration definition for Weather"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments(
    TypedDict, total=False
):
    project_id: Required[Annotated[str, PropertyInfo(alias="projectId")]]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments
    ]

    method: Literal["create_context"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    TypedDict, total=False
):
    repository_name: Required[Annotated[str, PropertyInfo(alias="repositoryName")]]

    ref: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ]

    method: Optional[Literal["install_extension_from_github"]]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    TypedDict, total=False
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ]

    method: Literal["list_sessions"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    TypedDict, total=False
):
    browser_settings: Annotated[object, PropertyInfo(alias="browserSettings")]

    extension_id: Annotated[Optional[str], PropertyInfo(alias="extensionId")]

    keep_alive: Annotated[bool, PropertyInfo(alias="keepAlive")]

    project_id: Annotated[Optional[str], PropertyInfo(alias="projectId")]

    proxies: Union[bool, Iterable[object]]

    timeout: int


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ]

    method: Literal["create_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ]

    method: Literal["get_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]

    status: Literal["REQUEST_RELEASE"]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ]

    method: Literal["complete_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ]

    method: Literal["get_live_urls"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments
    ]

    method: Literal["get_connect_url"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup(
    TypedDict, total=False
):
    connect_url: Optional[str]

    height: Optional[int]

    width: Optional[int]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "mouse_move",
            "left_click",
            "left_click_drag",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
            "cursor_position",
            "navigate",
            "refresh",
        ]
    ]

    connect_url: Optional[str]

    coordinate: Optional[Iterable[object]]

    text: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef(
    TypedDict, total=False
):
    setup: Required[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup
    ]
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments
    ]
    """The arguments for the remote browser"""

    method: Literal["perform_action"]

    provider: Literal["remote_browser"]


MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegration: TypeAlias = Union[
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationDummyIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef,
]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputSystem(
    TypedDict, total=False
):
    operation: Required[
        Literal[
            "create",
            "update",
            "patch",
            "create_or_update",
            "embed",
            "change_status",
            "search",
            "chat",
            "history",
            "delete",
            "get",
            "list",
        ]
    ]

    resource: Required[Literal["agent", "user", "task", "execution", "doc", "session", "job"]]

    arguments: Optional[object]

    resource_id: Optional[str]

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputTextEditor20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["text_editor_20241022"]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInput(
    TypedDict, total=False
):
    name: Required[str]

    type: Required[
        Literal[
            "function",
            "integration",
            "system",
            "api_call",
            "computer_20241022",
            "text_editor_20241022",
            "bash_20241022",
        ]
    ]

    api_call: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputAPICall
    ]
    """API call definition"""

    bash_20241022: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputBash20241022
    ]

    computer_20241022: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputComputer20241022
    ]
    """Anthropic new tools"""

    description: Optional[str]

    function: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputFunction
    ]
    """Function definition"""

    integration: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegration
    ]
    """Brave integration definition"""

    system: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputSystem
    ]
    """System definition"""

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputTextEditor20241022
    ]


MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1ToolRef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInput,
]


class MainIfElseWorkflowStepInputElsePromptStepInput(TypedDict, total=False):
    prompt: Required[Union[Iterable[MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0], str]]

    auto_run_tools: bool

    disable_cache: bool

    label: Optional[str]

    settings: Optional[ChatSettingsParam]

    tool_choice: Optional[MainIfElseWorkflowStepInputElsePromptStepInputToolChoice]

    tools: Union[Literal["all"], Iterable[MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1]]

    unwrap: bool


class MainIfElseWorkflowStepInputElseGetStep(TypedDict, total=False):
    get: Required[str]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseSetStep(TypedDict, total=False):
    set: Required[Dict[str, str]]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseLogStep(TypedDict, total=False):
    log: Required[str]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseYieldStep(TypedDict, total=False):
    workflow: Required[str]

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]], Literal["_"]]

    label: Optional[str]


_MainIfElseWorkflowStepInputElseReturnStepReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputElseReturnStepReservedKeywords",
    {
        "return": Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
    },
    total=False,
)


class MainIfElseWorkflowStepInputElseReturnStep(
    _MainIfElseWorkflowStepInputElseReturnStepReservedKeywords, total=False
):
    label: Optional[str]


class MainIfElseWorkflowStepInputElseSleepStepSleep(TypedDict, total=False):
    days: int

    hours: int

    minutes: int

    seconds: int


class MainIfElseWorkflowStepInputElseSleepStep(TypedDict, total=False):
    sleep: Required[MainIfElseWorkflowStepInputElseSleepStepSleep]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseErrorWorkflowStep(TypedDict, total=False):
    error: Required[str]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseWaitForInputStepWaitForInput(TypedDict, total=False):
    info: Required[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]]


class MainIfElseWorkflowStepInputElseWaitForInputStep(TypedDict, total=False):
    wait_for_input: Required[MainIfElseWorkflowStepInputElseWaitForInputStepWaitForInput]

    label: Optional[str]


MainIfElseWorkflowStepInputElse: TypeAlias = Union[
    MainIfElseWorkflowStepInputElseEvaluateStep,
    MainIfElseWorkflowStepInputElseToolCallStep,
    MainIfElseWorkflowStepInputElsePromptStepInput,
    MainIfElseWorkflowStepInputElseGetStep,
    MainIfElseWorkflowStepInputElseSetStep,
    MainIfElseWorkflowStepInputElseLogStep,
    MainIfElseWorkflowStepInputElseYieldStep,
    MainIfElseWorkflowStepInputElseReturnStep,
    MainIfElseWorkflowStepInputElseSleepStep,
    MainIfElseWorkflowStepInputElseErrorWorkflowStep,
    MainIfElseWorkflowStepInputElseWaitForInputStep,
]

_MainIfElseWorkflowStepInputReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputReservedKeywords",
    {
        "if": str,
        "else": Optional[MainIfElseWorkflowStepInputElse],
    },
    total=False,
)


class MainIfElseWorkflowStepInput(_MainIfElseWorkflowStepInputReservedKeywords, total=False):
    then: Required[MainIfElseWorkflowStepInputThen]

    label: Optional[str]


class MainSwitchStepInputSwitchThenEvaluateStep(TypedDict, total=False):
    evaluate: Required[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]]

    label: Optional[str]


class MainSwitchStepInputSwitchThenToolCallStep(TypedDict, total=False):
    tool: Required[str]

    arguments: Union[
        Dict[
            str,
            Union[
                Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
                Iterable[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]],
                str,
            ],
        ],
        Iterable[
            Dict[
                str,
                Union[
                    Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
                    Iterable[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]],
                    str,
                ],
            ]
        ],
        Literal["_"],
    ]

    label: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1Content(TypedDict, total=False):
    text: Required[str]

    type: Literal["text"]


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModelImageURL(
    TypedDict, total=False
):
    url: Required[str]

    detail: Literal["low", "high", "auto"]


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel(
    TypedDict, total=False
):
    image_url: Required[
        MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModelImageURL
    ]
    """The image URL"""

    type: Literal["image_url"]


MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1Content,
    MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel,
]


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction(
    TypedDict, total=False
):
    name: Required[str]

    arguments: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(
    TypedDict, total=False
):
    command: Optional[str]

    restart: bool


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall(TypedDict, total=False):
    function: Required[MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction]

    api_call: Optional[object]

    bash_20241022: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022
    ]

    computer_20241022: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ]

    integration: Optional[object]

    system: Optional[object]

    text_editor_20241022: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ]

    type: Literal["function"]


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenBash20241022(TypedDict, total=False):
    command: Optional[str]

    restart: bool


MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall,
    MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022,
    MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenBash20241022,
]

_MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ReservedKeywords = TypedDict(
    "_MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ReservedKeywords",
    {
        "continue": Optional[bool],
    },
    total=False,
)


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0(
    _MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ReservedKeywords, total=False
):
    content: Required[
        Union[
            List[str],
            Iterable[MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1],
            str,
            None,
        ]
    ]

    role: Required[Literal["user", "assistant", "system", "tool"]]

    name: Optional[str]

    tool_call_id: Optional[str]

    tool_calls: Optional[Iterable[MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCall]]


class MainSwitchStepInputSwitchThenPromptStepInputToolChoiceNamedToolChoiceFunction(TypedDict, total=False):
    name: Required[str]

    arguments: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolChoiceNamedToolChoice(TypedDict, total=False):
    function: Optional[MainSwitchStepInputSwitchThenPromptStepInputToolChoiceNamedToolChoiceFunction]


MainSwitchStepInputSwitchThenPromptStepInputToolChoice: TypeAlias = Union[
    Literal["auto", "none"], MainSwitchStepInputSwitchThenPromptStepInputToolChoiceNamedToolChoice
]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByID(TypedDict, total=False):
    id: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByName(TypedDict, total=False):
    name: Optional[str]


MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByID,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRef(TypedDict, total=False):
    ref: Required[MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRef]
    """Reference to a tool by id"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputAPICall(
    TypedDict, total=False
):
    method: Required[Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]]

    url: Required[str]

    content: Optional[str]

    cookies: Optional[Dict[str, str]]

    data: Optional[object]

    follow_redirects: Optional[bool]

    headers: Optional[Dict[str, str]]

    json: Optional[object]

    params: Union[str, object, None]

    schema: Optional[object]

    timeout: Optional[int]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputBash20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["bash_20241022"]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputComputer20241022(
    TypedDict, total=False
):
    display_height_px: int

    display_number: int

    display_width_px: int

    name: str

    type: Literal["computer_20241022"]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputFunction(
    TypedDict, total=False
):
    description: Optional[object]

    name: Optional[object]

    parameters: Optional[object]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationDummyIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[object]

    method: Optional[str]

    provider: Literal["dummy"]

    setup: Optional[object]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefArguments
    ]
    """Arguments for Brave Search"""

    method: Optional[str]

    provider: Literal["brave"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefSetup
    ]
    """Integration definition for Brave Search"""


_MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArguments(
    _MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefSetup(
    TypedDict, total=False
):
    host: Required[str]

    password: Required[str]

    port: Required[int]

    user: Required[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArguments
    ]
    """Arguments for Email sending"""

    method: Optional[str]

    provider: Literal["email"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefSetup
    ]
    """Setup parameters for Email integration"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefArguments(
    TypedDict, total=False
):
    url: Required[str]

    mode: Literal["scrape"]

    params: Optional[object]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefSetup(
    TypedDict, total=False
):
    spider_api_key: Required[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefArguments
    ]
    """Arguments for Spider integration"""

    method: Optional[str]

    provider: Literal["spider"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefSetup
    ]
    """Setup parameters for Spider integration"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    load_max_docs: int


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments
    ]
    """Arguments for Wikipedia Search"""

    method: Optional[str]

    provider: Literal["wikipedia"]

    setup: Optional[object]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefArguments(
    TypedDict, total=False
):
    location: Required[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefSetup(
    TypedDict, total=False
):
    openweathermap_api_key: Required[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefArguments
    ]
    """Arguments for Weather"""

    method: Optional[str]

    provider: Literal["weather"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefSetup
    ]
    """Integration definition for Weather"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments(
    TypedDict, total=False
):
    project_id: Required[Annotated[str, PropertyInfo(alias="projectId")]]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments
    ]

    method: Literal["create_context"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    TypedDict, total=False
):
    repository_name: Required[Annotated[str, PropertyInfo(alias="repositoryName")]]

    ref: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ]

    method: Optional[Literal["install_extension_from_github"]]

    provider: Literal["browserbase"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    TypedDict, total=False
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ]

    method: Literal["list_sessions"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    TypedDict, total=False
):
    browser_settings: Annotated[object, PropertyInfo(alias="browserSettings")]

    extension_id: Annotated[Optional[str], PropertyInfo(alias="extensionId")]

    keep_alive: Annotated[bool, PropertyInfo(alias="keepAlive")]

    project_id: Annotated[Optional[str], PropertyInfo(alias="projectId")]

    proxies: Union[bool, Iterable[object]]

    timeout: int


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ]

    method: Literal["create_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ]

    method: Literal["get_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]

    status: Literal["REQUEST_RELEASE"]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ]

    method: Literal["complete_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ]

    method: Literal["get_live_urls"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments
    ]

    method: Literal["get_connect_url"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup(
    TypedDict, total=False
):
    connect_url: Optional[str]

    height: Optional[int]

    width: Optional[int]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "mouse_move",
            "left_click",
            "left_click_drag",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
            "cursor_position",
            "navigate",
            "refresh",
        ]
    ]

    connect_url: Optional[str]

    coordinate: Optional[Iterable[object]]

    text: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef(
    TypedDict, total=False
):
    setup: Required[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup
    ]
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments
    ]
    """The arguments for the remote browser"""

    method: Literal["perform_action"]

    provider: Literal["remote_browser"]


MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegration: TypeAlias = Union[
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationDummyIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef,
]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputSystem(
    TypedDict, total=False
):
    operation: Required[
        Literal[
            "create",
            "update",
            "patch",
            "create_or_update",
            "embed",
            "change_status",
            "search",
            "chat",
            "history",
            "delete",
            "get",
            "list",
        ]
    ]

    resource: Required[Literal["agent", "user", "task", "execution", "doc", "session", "job"]]

    arguments: Optional[object]

    resource_id: Optional[str]

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputTextEditor20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["text_editor_20241022"]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInput(
    TypedDict, total=False
):
    name: Required[str]

    type: Required[
        Literal[
            "function",
            "integration",
            "system",
            "api_call",
            "computer_20241022",
            "text_editor_20241022",
            "bash_20241022",
        ]
    ]

    api_call: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputAPICall
    ]
    """API call definition"""

    bash_20241022: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputBash20241022
    ]

    computer_20241022: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputComputer20241022
    ]
    """Anthropic new tools"""

    description: Optional[str]

    function: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputFunction
    ]
    """Function definition"""

    integration: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegration
    ]
    """Brave integration definition"""

    system: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputSystem
    ]
    """System definition"""

    text_editor_20241022: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputTextEditor20241022
    ]


MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1: TypeAlias = Union[
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInput,
]


class MainSwitchStepInputSwitchThenPromptStepInput(TypedDict, total=False):
    prompt: Required[Union[Iterable[MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0], str]]

    auto_run_tools: bool

    disable_cache: bool

    label: Optional[str]

    settings: Optional[ChatSettingsParam]

    tool_choice: Optional[MainSwitchStepInputSwitchThenPromptStepInputToolChoice]

    tools: Union[Literal["all"], Iterable[MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1]]

    unwrap: bool


class MainSwitchStepInputSwitchThenGetStep(TypedDict, total=False):
    get: Required[str]

    label: Optional[str]


class MainSwitchStepInputSwitchThenSetStep(TypedDict, total=False):
    set: Required[Dict[str, str]]

    label: Optional[str]


class MainSwitchStepInputSwitchThenLogStep(TypedDict, total=False):
    log: Required[str]

    label: Optional[str]


class MainSwitchStepInputSwitchThenYieldStep(TypedDict, total=False):
    workflow: Required[str]

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]], Literal["_"]]

    label: Optional[str]


_MainSwitchStepInputSwitchThenReturnStepReservedKeywords = TypedDict(
    "_MainSwitchStepInputSwitchThenReturnStepReservedKeywords",
    {
        "return": Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
    },
    total=False,
)


class MainSwitchStepInputSwitchThenReturnStep(_MainSwitchStepInputSwitchThenReturnStepReservedKeywords, total=False):
    label: Optional[str]


class MainSwitchStepInputSwitchThenSleepStepSleep(TypedDict, total=False):
    days: int

    hours: int

    minutes: int

    seconds: int


class MainSwitchStepInputSwitchThenSleepStep(TypedDict, total=False):
    sleep: Required[MainSwitchStepInputSwitchThenSleepStepSleep]

    label: Optional[str]


class MainSwitchStepInputSwitchThenErrorWorkflowStep(TypedDict, total=False):
    error: Required[str]

    label: Optional[str]


class MainSwitchStepInputSwitchThenWaitForInputStepWaitForInput(TypedDict, total=False):
    info: Required[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]]


class MainSwitchStepInputSwitchThenWaitForInputStep(TypedDict, total=False):
    wait_for_input: Required[MainSwitchStepInputSwitchThenWaitForInputStepWaitForInput]

    label: Optional[str]


MainSwitchStepInputSwitchThen: TypeAlias = Union[
    MainSwitchStepInputSwitchThenEvaluateStep,
    MainSwitchStepInputSwitchThenToolCallStep,
    MainSwitchStepInputSwitchThenPromptStepInput,
    MainSwitchStepInputSwitchThenGetStep,
    MainSwitchStepInputSwitchThenSetStep,
    MainSwitchStepInputSwitchThenLogStep,
    MainSwitchStepInputSwitchThenYieldStep,
    MainSwitchStepInputSwitchThenReturnStep,
    MainSwitchStepInputSwitchThenSleepStep,
    MainSwitchStepInputSwitchThenErrorWorkflowStep,
    MainSwitchStepInputSwitchThenWaitForInputStep,
]


class MainSwitchStepInputSwitch(TypedDict, total=False):
    case: Required[Union[Literal["_"], str]]

    then: Required[MainSwitchStepInputSwitchThen]


class MainSwitchStepInput(TypedDict, total=False):
    switch: Required[Iterable[MainSwitchStepInputSwitch]]

    label: Optional[str]


class MainForeachStepInputForeachDoWaitForInputStepWaitForInput(TypedDict, total=False):
    info: Required[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]]


class MainForeachStepInputForeachDoWaitForInputStep(TypedDict, total=False):
    wait_for_input: Required[MainForeachStepInputForeachDoWaitForInputStepWaitForInput]

    label: Optional[str]


class MainForeachStepInputForeachDoEvaluateStep(TypedDict, total=False):
    evaluate: Required[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]]

    label: Optional[str]


class MainForeachStepInputForeachDoToolCallStep(TypedDict, total=False):
    tool: Required[str]

    arguments: Union[
        Dict[
            str,
            Union[
                Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
                Iterable[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]],
                str,
            ],
        ],
        Iterable[
            Dict[
                str,
                Union[
                    Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
                    Iterable[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]],
                    str,
                ],
            ]
        ],
        Literal["_"],
    ]

    label: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1Content(TypedDict, total=False):
    text: Required[str]

    type: Literal["text"]


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModelImageURL(
    TypedDict, total=False
):
    url: Required[str]

    detail: Literal["low", "high", "auto"]


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel(
    TypedDict, total=False
):
    image_url: Required[
        MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModelImageURL
    ]
    """The image URL"""

    type: Literal["image_url"]


MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1Content,
    MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel,
]


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction(
    TypedDict, total=False
):
    name: Required[str]

    arguments: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(
    TypedDict, total=False
):
    command: Optional[str]

    restart: bool


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall(TypedDict, total=False):
    function: Required[MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction]

    api_call: Optional[object]

    bash_20241022: Optional[
        MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022
    ]

    computer_20241022: Optional[
        MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ]

    integration: Optional[object]

    system: Optional[object]

    text_editor_20241022: Optional[
        MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ]

    type: Literal["function"]


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenBash20241022(TypedDict, total=False):
    command: Optional[str]

    restart: bool


MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall,
    MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022,
    MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenBash20241022,
]

_MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ReservedKeywords = TypedDict(
    "_MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ReservedKeywords",
    {
        "continue": Optional[bool],
    },
    total=False,
)


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0(
    _MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ReservedKeywords, total=False
):
    content: Required[
        Union[
            List[str],
            Iterable[MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1],
            str,
            None,
        ]
    ]

    role: Required[Literal["user", "assistant", "system", "tool"]]

    name: Optional[str]

    tool_call_id: Optional[str]

    tool_calls: Optional[Iterable[MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCall]]


class MainForeachStepInputForeachDoPromptStepInputToolChoiceNamedToolChoiceFunction(TypedDict, total=False):
    name: Required[str]

    arguments: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputToolChoiceNamedToolChoice(TypedDict, total=False):
    function: Optional[MainForeachStepInputForeachDoPromptStepInputToolChoiceNamedToolChoiceFunction]


MainForeachStepInputForeachDoPromptStepInputToolChoice: TypeAlias = Union[
    Literal["auto", "none"], MainForeachStepInputForeachDoPromptStepInputToolChoiceNamedToolChoice
]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRefToolRefByID(TypedDict, total=False):
    id: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRefToolRefByName(TypedDict, total=False):
    name: Optional[str]


MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRefToolRefByID,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRef(TypedDict, total=False):
    ref: Required[MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRef]
    """Reference to a tool by id"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputAPICall(
    TypedDict, total=False
):
    method: Required[Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]]

    url: Required[str]

    content: Optional[str]

    cookies: Optional[Dict[str, str]]

    data: Optional[object]

    follow_redirects: Optional[bool]

    headers: Optional[Dict[str, str]]

    json: Optional[object]

    params: Union[str, object, None]

    schema: Optional[object]

    timeout: Optional[int]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputBash20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["bash_20241022"]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputComputer20241022(
    TypedDict, total=False
):
    display_height_px: int

    display_number: int

    display_width_px: int

    name: str

    type: Literal["computer_20241022"]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputFunction(
    TypedDict, total=False
):
    description: Optional[object]

    name: Optional[object]

    parameters: Optional[object]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationDummyIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[object]

    method: Optional[str]

    provider: Literal["dummy"]

    setup: Optional[object]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefArguments
    ]
    """Arguments for Brave Search"""

    method: Optional[str]

    provider: Literal["brave"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefSetup
    ]
    """Integration definition for Brave Search"""


_MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArguments(
    _MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefSetup(
    TypedDict, total=False
):
    host: Required[str]

    password: Required[str]

    port: Required[int]

    user: Required[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArguments
    ]
    """Arguments for Email sending"""

    method: Optional[str]

    provider: Literal["email"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefSetup
    ]
    """Setup parameters for Email integration"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefArguments(
    TypedDict, total=False
):
    url: Required[str]

    mode: Literal["scrape"]

    params: Optional[object]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefSetup(
    TypedDict, total=False
):
    spider_api_key: Required[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefArguments
    ]
    """Arguments for Spider integration"""

    method: Optional[str]

    provider: Literal["spider"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefSetup
    ]
    """Setup parameters for Spider integration"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    load_max_docs: int


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments
    ]
    """Arguments for Wikipedia Search"""

    method: Optional[str]

    provider: Literal["wikipedia"]

    setup: Optional[object]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefArguments(
    TypedDict, total=False
):
    location: Required[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefSetup(
    TypedDict, total=False
):
    openweathermap_api_key: Required[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefArguments
    ]
    """Arguments for Weather"""

    method: Optional[str]

    provider: Literal["weather"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefSetup
    ]
    """Integration definition for Weather"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments(
    TypedDict, total=False
):
    project_id: Required[Annotated[str, PropertyInfo(alias="projectId")]]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments
    ]

    method: Literal["create_context"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    TypedDict, total=False
):
    repository_name: Required[Annotated[str, PropertyInfo(alias="repositoryName")]]

    ref: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ]

    method: Optional[Literal["install_extension_from_github"]]

    provider: Literal["browserbase"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    TypedDict, total=False
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ]

    method: Literal["list_sessions"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    TypedDict, total=False
):
    browser_settings: Annotated[object, PropertyInfo(alias="browserSettings")]

    extension_id: Annotated[Optional[str], PropertyInfo(alias="extensionId")]

    keep_alive: Annotated[bool, PropertyInfo(alias="keepAlive")]

    project_id: Annotated[Optional[str], PropertyInfo(alias="projectId")]

    proxies: Union[bool, Iterable[object]]

    timeout: int


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ]

    method: Literal["create_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ]

    method: Literal["get_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]

    status: Literal["REQUEST_RELEASE"]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ]

    method: Literal["complete_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ]

    method: Literal["get_live_urls"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments
    ]

    method: Literal["get_connect_url"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup(
    TypedDict, total=False
):
    connect_url: Optional[str]

    height: Optional[int]

    width: Optional[int]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "mouse_move",
            "left_click",
            "left_click_drag",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
            "cursor_position",
            "navigate",
            "refresh",
        ]
    ]

    connect_url: Optional[str]

    coordinate: Optional[Iterable[object]]

    text: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef(
    TypedDict, total=False
):
    setup: Required[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup
    ]
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments
    ]
    """The arguments for the remote browser"""

    method: Literal["perform_action"]

    provider: Literal["remote_browser"]


MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegration: TypeAlias = Union[
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationDummyIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef,
]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputSystem(
    TypedDict, total=False
):
    operation: Required[
        Literal[
            "create",
            "update",
            "patch",
            "create_or_update",
            "embed",
            "change_status",
            "search",
            "chat",
            "history",
            "delete",
            "get",
            "list",
        ]
    ]

    resource: Required[Literal["agent", "user", "task", "execution", "doc", "session", "job"]]

    arguments: Optional[object]

    resource_id: Optional[str]

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputTextEditor20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["text_editor_20241022"]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInput(
    TypedDict, total=False
):
    name: Required[str]

    type: Required[
        Literal[
            "function",
            "integration",
            "system",
            "api_call",
            "computer_20241022",
            "text_editor_20241022",
            "bash_20241022",
        ]
    ]

    api_call: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputAPICall
    ]
    """API call definition"""

    bash_20241022: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputBash20241022
    ]

    computer_20241022: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputComputer20241022
    ]
    """Anthropic new tools"""

    description: Optional[str]

    function: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputFunction
    ]
    """Function definition"""

    integration: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegration
    ]
    """Brave integration definition"""

    system: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputSystem
    ]
    """System definition"""

    text_editor_20241022: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputTextEditor20241022
    ]


MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1: TypeAlias = Union[
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInput,
]


class MainForeachStepInputForeachDoPromptStepInput(TypedDict, total=False):
    prompt: Required[Union[Iterable[MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0], str]]

    auto_run_tools: bool

    disable_cache: bool

    label: Optional[str]

    settings: Optional[ChatSettingsParam]

    tool_choice: Optional[MainForeachStepInputForeachDoPromptStepInputToolChoice]

    tools: Union[Literal["all"], Iterable[MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1]]

    unwrap: bool


class MainForeachStepInputForeachDoGetStep(TypedDict, total=False):
    get: Required[str]

    label: Optional[str]


class MainForeachStepInputForeachDoSetStep(TypedDict, total=False):
    set: Required[Dict[str, str]]

    label: Optional[str]


class MainForeachStepInputForeachDoLogStep(TypedDict, total=False):
    log: Required[str]

    label: Optional[str]


class MainForeachStepInputForeachDoYieldStep(TypedDict, total=False):
    workflow: Required[str]

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]], Literal["_"]]

    label: Optional[str]


MainForeachStepInputForeachDo: TypeAlias = Union[
    MainForeachStepInputForeachDoWaitForInputStep,
    MainForeachStepInputForeachDoEvaluateStep,
    MainForeachStepInputForeachDoToolCallStep,
    MainForeachStepInputForeachDoPromptStepInput,
    MainForeachStepInputForeachDoGetStep,
    MainForeachStepInputForeachDoSetStep,
    MainForeachStepInputForeachDoLogStep,
    MainForeachStepInputForeachDoYieldStep,
]

_MainForeachStepInputForeachReservedKeywords = TypedDict(
    "_MainForeachStepInputForeachReservedKeywords",
    {
        "in": str,
    },
    total=False,
)


class MainForeachStepInputForeach(_MainForeachStepInputForeachReservedKeywords, total=False):
    do: Required[MainForeachStepInputForeachDo]


class MainForeachStepInput(TypedDict, total=False):
    foreach: Required[MainForeachStepInputForeach]

    label: Optional[str]


class MainParallelStepInputParallelEvaluateStep(TypedDict, total=False):
    evaluate: Required[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]]

    label: Optional[str]


class MainParallelStepInputParallelToolCallStep(TypedDict, total=False):
    tool: Required[str]

    arguments: Union[
        Dict[
            str,
            Union[
                Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
                Iterable[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]],
                str,
            ],
        ],
        Iterable[
            Dict[
                str,
                Union[
                    Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
                    Iterable[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]],
                    str,
                ],
            ]
        ],
        Literal["_"],
    ]

    label: Optional[str]


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1Content(TypedDict, total=False):
    text: Required[str]

    type: Literal["text"]


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModelImageURL(
    TypedDict, total=False
):
    url: Required[str]

    detail: Literal["low", "high", "auto"]


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel(
    TypedDict, total=False
):
    image_url: Required[
        MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModelImageURL
    ]
    """The image URL"""

    type: Literal["image_url"]


MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1Content,
    MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel,
]


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction(
    TypedDict, total=False
):
    name: Required[str]

    arguments: Optional[str]


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(
    TypedDict, total=False
):
    command: Optional[str]

    restart: bool


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall(TypedDict, total=False):
    function: Required[MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction]

    api_call: Optional[object]

    bash_20241022: Optional[
        MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022
    ]

    computer_20241022: Optional[
        MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ]

    integration: Optional[object]

    system: Optional[object]

    text_editor_20241022: Optional[
        MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ]

    type: Literal["function"]


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenBash20241022(TypedDict, total=False):
    command: Optional[str]

    restart: bool


MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall,
    MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022,
    MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenBash20241022,
]

_MainParallelStepInputParallelPromptStepInputPromptUnionMember0ReservedKeywords = TypedDict(
    "_MainParallelStepInputParallelPromptStepInputPromptUnionMember0ReservedKeywords",
    {
        "continue": Optional[bool],
    },
    total=False,
)


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0(
    _MainParallelStepInputParallelPromptStepInputPromptUnionMember0ReservedKeywords, total=False
):
    content: Required[
        Union[
            List[str],
            Iterable[MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1],
            str,
            None,
        ]
    ]

    role: Required[Literal["user", "assistant", "system", "tool"]]

    name: Optional[str]

    tool_call_id: Optional[str]

    tool_calls: Optional[Iterable[MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCall]]


class MainParallelStepInputParallelPromptStepInputToolChoiceNamedToolChoiceFunction(TypedDict, total=False):
    name: Required[str]

    arguments: Optional[str]


class MainParallelStepInputParallelPromptStepInputToolChoiceNamedToolChoice(TypedDict, total=False):
    function: Optional[MainParallelStepInputParallelPromptStepInputToolChoiceNamedToolChoiceFunction]


MainParallelStepInputParallelPromptStepInputToolChoice: TypeAlias = Union[
    Literal["auto", "none"], MainParallelStepInputParallelPromptStepInputToolChoiceNamedToolChoice
]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRefToolRefByID(TypedDict, total=False):
    id: Optional[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRefToolRefByName(TypedDict, total=False):
    name: Optional[str]


MainParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRefToolRefByID,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRef(TypedDict, total=False):
    ref: Required[MainParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRef]
    """Reference to a tool by id"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputAPICall(
    TypedDict, total=False
):
    method: Required[Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]]

    url: Required[str]

    content: Optional[str]

    cookies: Optional[Dict[str, str]]

    data: Optional[object]

    follow_redirects: Optional[bool]

    headers: Optional[Dict[str, str]]

    json: Optional[object]

    params: Union[str, object, None]

    schema: Optional[object]

    timeout: Optional[int]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputBash20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["bash_20241022"]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputComputer20241022(
    TypedDict, total=False
):
    display_height_px: int

    display_number: int

    display_width_px: int

    name: str

    type: Literal["computer_20241022"]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputFunction(
    TypedDict, total=False
):
    description: Optional[object]

    name: Optional[object]

    parameters: Optional[object]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationDummyIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[object]

    method: Optional[str]

    provider: Literal["dummy"]

    setup: Optional[object]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefArguments
    ]
    """Arguments for Brave Search"""

    method: Optional[str]

    provider: Literal["brave"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefSetup
    ]
    """Integration definition for Brave Search"""


_MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArguments(
    _MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefSetup(
    TypedDict, total=False
):
    host: Required[str]

    password: Required[str]

    port: Required[int]

    user: Required[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArguments
    ]
    """Arguments for Email sending"""

    method: Optional[str]

    provider: Literal["email"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefSetup
    ]
    """Setup parameters for Email integration"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefArguments(
    TypedDict, total=False
):
    url: Required[str]

    mode: Literal["scrape"]

    params: Optional[object]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefSetup(
    TypedDict, total=False
):
    spider_api_key: Required[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefArguments
    ]
    """Arguments for Spider integration"""

    method: Optional[str]

    provider: Literal["spider"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefSetup
    ]
    """Setup parameters for Spider integration"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    load_max_docs: int


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments
    ]
    """Arguments for Wikipedia Search"""

    method: Optional[str]

    provider: Literal["wikipedia"]

    setup: Optional[object]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefArguments(
    TypedDict, total=False
):
    location: Required[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefSetup(
    TypedDict, total=False
):
    openweathermap_api_key: Required[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefArguments
    ]
    """Arguments for Weather"""

    method: Optional[str]

    provider: Literal["weather"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefSetup
    ]
    """Integration definition for Weather"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments(
    TypedDict, total=False
):
    project_id: Required[Annotated[str, PropertyInfo(alias="projectId")]]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments
    ]

    method: Literal["create_context"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    TypedDict, total=False
):
    repository_name: Required[Annotated[str, PropertyInfo(alias="repositoryName")]]

    ref: Optional[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ]

    method: Optional[Literal["install_extension_from_github"]]

    provider: Literal["browserbase"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    TypedDict, total=False
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ]

    method: Literal["list_sessions"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    TypedDict, total=False
):
    browser_settings: Annotated[object, PropertyInfo(alias="browserSettings")]

    extension_id: Annotated[Optional[str], PropertyInfo(alias="extensionId")]

    keep_alive: Annotated[bool, PropertyInfo(alias="keepAlive")]

    project_id: Annotated[Optional[str], PropertyInfo(alias="projectId")]

    proxies: Union[bool, Iterable[object]]

    timeout: int


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ]

    method: Literal["create_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ]

    method: Literal["get_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]

    status: Literal["REQUEST_RELEASE"]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ]

    method: Literal["complete_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ]

    method: Literal["get_live_urls"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments
    ]

    method: Literal["get_connect_url"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup(
    TypedDict, total=False
):
    connect_url: Optional[str]

    height: Optional[int]

    width: Optional[int]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "mouse_move",
            "left_click",
            "left_click_drag",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
            "cursor_position",
            "navigate",
            "refresh",
        ]
    ]

    connect_url: Optional[str]

    coordinate: Optional[Iterable[object]]

    text: Optional[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef(
    TypedDict, total=False
):
    setup: Required[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup
    ]
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments
    ]
    """The arguments for the remote browser"""

    method: Literal["perform_action"]

    provider: Literal["remote_browser"]


MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegration: TypeAlias = Union[
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationDummyIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef,
]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputSystem(
    TypedDict, total=False
):
    operation: Required[
        Literal[
            "create",
            "update",
            "patch",
            "create_or_update",
            "embed",
            "change_status",
            "search",
            "chat",
            "history",
            "delete",
            "get",
            "list",
        ]
    ]

    resource: Required[Literal["agent", "user", "task", "execution", "doc", "session", "job"]]

    arguments: Optional[object]

    resource_id: Optional[str]

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputTextEditor20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["text_editor_20241022"]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInput(
    TypedDict, total=False
):
    name: Required[str]

    type: Required[
        Literal[
            "function",
            "integration",
            "system",
            "api_call",
            "computer_20241022",
            "text_editor_20241022",
            "bash_20241022",
        ]
    ]

    api_call: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputAPICall
    ]
    """API call definition"""

    bash_20241022: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputBash20241022
    ]

    computer_20241022: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputComputer20241022
    ]
    """Anthropic new tools"""

    description: Optional[str]

    function: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputFunction
    ]
    """Function definition"""

    integration: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegration
    ]
    """Brave integration definition"""

    system: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputSystem
    ]
    """System definition"""

    text_editor_20241022: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputTextEditor20241022
    ]


MainParallelStepInputParallelPromptStepInputToolsUnionMember1: TypeAlias = Union[
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInput,
]


class MainParallelStepInputParallelPromptStepInput(TypedDict, total=False):
    prompt: Required[Union[Iterable[MainParallelStepInputParallelPromptStepInputPromptUnionMember0], str]]

    auto_run_tools: bool

    disable_cache: bool

    label: Optional[str]

    settings: Optional[ChatSettingsParam]

    tool_choice: Optional[MainParallelStepInputParallelPromptStepInputToolChoice]

    tools: Union[Literal["all"], Iterable[MainParallelStepInputParallelPromptStepInputToolsUnionMember1]]

    unwrap: bool


class MainParallelStepInputParallelGetStep(TypedDict, total=False):
    get: Required[str]

    label: Optional[str]


class MainParallelStepInputParallelSetStep(TypedDict, total=False):
    set: Required[Dict[str, str]]

    label: Optional[str]


class MainParallelStepInputParallelLogStep(TypedDict, total=False):
    log: Required[str]

    label: Optional[str]


class MainParallelStepInputParallelYieldStep(TypedDict, total=False):
    workflow: Required[str]

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]], Literal["_"]]

    label: Optional[str]


MainParallelStepInputParallel: TypeAlias = Union[
    MainParallelStepInputParallelEvaluateStep,
    MainParallelStepInputParallelToolCallStep,
    MainParallelStepInputParallelPromptStepInput,
    MainParallelStepInputParallelGetStep,
    MainParallelStepInputParallelSetStep,
    MainParallelStepInputParallelLogStep,
    MainParallelStepInputParallelYieldStep,
]


class MainParallelStepInput(TypedDict, total=False):
    parallel: Required[Iterable[MainParallelStepInputParallel]]

    label: Optional[str]


class MainMainInputMapEvaluateStep(TypedDict, total=False):
    evaluate: Required[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]]

    label: Optional[str]


class MainMainInputMapToolCallStep(TypedDict, total=False):
    tool: Required[str]

    arguments: Union[
        Dict[
            str,
            Union[
                Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
                Iterable[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]],
                str,
            ],
        ],
        Iterable[
            Dict[
                str,
                Union[
                    Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
                    Iterable[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]],
                    str,
                ],
            ]
        ],
        Literal["_"],
    ]

    label: Optional[str]


class MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1Content(TypedDict, total=False):
    text: Required[str]

    type: Literal["text"]


class MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModelImageURL(TypedDict, total=False):
    url: Required[str]

    detail: Literal["low", "high", "auto"]


class MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel(TypedDict, total=False):
    image_url: Required[MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModelImageURL]
    """The image URL"""

    type: Literal["image_url"]


MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1Content,
    MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel,
]


class MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction(TypedDict, total=False):
    name: Required[str]

    arguments: Optional[str]


class MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(TypedDict, total=False):
    command: Optional[str]

    restart: bool


class MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall(TypedDict, total=False):
    function: Required[MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction]

    api_call: Optional[object]

    bash_20241022: Optional[MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022]

    computer_20241022: Optional[
        MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ]

    integration: Optional[object]

    system: Optional[object]

    text_editor_20241022: Optional[
        MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ]

    type: Literal["function"]


class MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022(TypedDict, total=False):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022(TypedDict, total=False):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenBash20241022(TypedDict, total=False):
    command: Optional[str]

    restart: bool


MainMainInputMapPromptStepInputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall,
    MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022,
    MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenBash20241022,
]

_MainMainInputMapPromptStepInputPromptUnionMember0ReservedKeywords = TypedDict(
    "_MainMainInputMapPromptStepInputPromptUnionMember0ReservedKeywords",
    {
        "continue": Optional[bool],
    },
    total=False,
)


class MainMainInputMapPromptStepInputPromptUnionMember0(
    _MainMainInputMapPromptStepInputPromptUnionMember0ReservedKeywords, total=False
):
    content: Required[
        Union[List[str], Iterable[MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1], str, None]
    ]

    role: Required[Literal["user", "assistant", "system", "tool"]]

    name: Optional[str]

    tool_call_id: Optional[str]

    tool_calls: Optional[Iterable[MainMainInputMapPromptStepInputPromptUnionMember0ToolCall]]


class MainMainInputMapPromptStepInputToolChoiceNamedToolChoiceFunction(TypedDict, total=False):
    name: Required[str]

    arguments: Optional[str]


class MainMainInputMapPromptStepInputToolChoiceNamedToolChoice(TypedDict, total=False):
    function: Optional[MainMainInputMapPromptStepInputToolChoiceNamedToolChoiceFunction]


MainMainInputMapPromptStepInputToolChoice: TypeAlias = Union[
    Literal["auto", "none"], MainMainInputMapPromptStepInputToolChoiceNamedToolChoice
]


class MainMainInputMapPromptStepInputToolsUnionMember1ToolRefRefToolRefByID(TypedDict, total=False):
    id: Optional[str]


class MainMainInputMapPromptStepInputToolsUnionMember1ToolRefRefToolRefByName(TypedDict, total=False):
    name: Optional[str]


MainMainInputMapPromptStepInputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainMainInputMapPromptStepInputToolsUnionMember1ToolRefRefToolRefByID,
    MainMainInputMapPromptStepInputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainMainInputMapPromptStepInputToolsUnionMember1ToolRef(TypedDict, total=False):
    ref: Required[MainMainInputMapPromptStepInputToolsUnionMember1ToolRefRef]
    """Reference to a tool by id"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputAPICall(
    TypedDict, total=False
):
    method: Required[Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]]

    url: Required[str]

    content: Optional[str]

    cookies: Optional[Dict[str, str]]

    data: Optional[object]

    follow_redirects: Optional[bool]

    headers: Optional[Dict[str, str]]

    json: Optional[object]

    params: Union[str, object, None]

    schema: Optional[object]

    timeout: Optional[int]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputBash20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["bash_20241022"]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputComputer20241022(
    TypedDict, total=False
):
    display_height_px: int

    display_number: int

    display_width_px: int

    name: str

    type: Literal["computer_20241022"]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputFunction(
    TypedDict, total=False
):
    description: Optional[object]

    name: Optional[object]

    parameters: Optional[object]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationDummyIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[object]

    method: Optional[str]

    provider: Literal["dummy"]

    setup: Optional[object]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefArguments
    ]
    """Arguments for Brave Search"""

    method: Optional[str]

    provider: Literal["brave"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDefSetup
    ]
    """Integration definition for Brave Search"""


_MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArguments(
    _MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefSetup(
    TypedDict, total=False
):
    host: Required[str]

    password: Required[str]

    port: Required[int]

    user: Required[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefArguments
    ]
    """Arguments for Email sending"""

    method: Optional[str]

    provider: Literal["email"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDefSetup
    ]
    """Setup parameters for Email integration"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefArguments(
    TypedDict, total=False
):
    url: Required[str]

    mode: Literal["scrape"]

    params: Optional[object]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefSetup(
    TypedDict, total=False
):
    spider_api_key: Required[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefArguments
    ]
    """Arguments for Spider integration"""

    method: Optional[str]

    provider: Literal["spider"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDefSetup
    ]
    """Setup parameters for Spider integration"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    load_max_docs: int


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments
    ]
    """Arguments for Wikipedia Search"""

    method: Optional[str]

    provider: Literal["wikipedia"]

    setup: Optional[object]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefArguments(
    TypedDict, total=False
):
    location: Required[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefSetup(
    TypedDict, total=False
):
    openweathermap_api_key: Required[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefArguments
    ]
    """Arguments for Weather"""

    method: Optional[str]

    provider: Literal["weather"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDefSetup
    ]
    """Integration definition for Weather"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments(
    TypedDict, total=False
):
    project_id: Required[Annotated[str, PropertyInfo(alias="projectId")]]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments
    ]

    method: Literal["create_context"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    TypedDict, total=False
):
    repository_name: Required[Annotated[str, PropertyInfo(alias="repositoryName")]]

    ref: Optional[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ]

    method: Optional[Literal["install_extension_from_github"]]

    provider: Literal["browserbase"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    TypedDict, total=False
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ]

    method: Literal["list_sessions"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    TypedDict, total=False
):
    browser_settings: Annotated[object, PropertyInfo(alias="browserSettings")]

    extension_id: Annotated[Optional[str], PropertyInfo(alias="extensionId")]

    keep_alive: Annotated[bool, PropertyInfo(alias="keepAlive")]

    project_id: Annotated[Optional[str], PropertyInfo(alias="projectId")]

    proxies: Union[bool, Iterable[object]]

    timeout: int


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ]

    method: Literal["create_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ]

    method: Literal["get_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]

    status: Literal["REQUEST_RELEASE"]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ]

    method: Literal["complete_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ]

    method: Literal["get_live_urls"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments
    ]

    method: Literal["get_connect_url"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup(
    TypedDict, total=False
):
    connect_url: Optional[str]

    height: Optional[int]

    width: Optional[int]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "mouse_move",
            "left_click",
            "left_click_drag",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
            "cursor_position",
            "navigate",
            "refresh",
        ]
    ]

    connect_url: Optional[str]

    coordinate: Optional[Iterable[object]]

    text: Optional[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef(
    TypedDict, total=False
):
    setup: Required[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup
    ]
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments
    ]
    """The arguments for the remote browser"""

    method: Literal["perform_action"]

    provider: Literal["remote_browser"]


MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegration: TypeAlias = Union[
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationDummyIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBraveIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationEmailIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationSpiderIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWikipediaIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationWeatherIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef,
]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputSystem(
    TypedDict, total=False
):
    operation: Required[
        Literal[
            "create",
            "update",
            "patch",
            "create_or_update",
            "embed",
            "change_status",
            "search",
            "chat",
            "history",
            "delete",
            "get",
            "list",
        ]
    ]

    resource: Required[Literal["agent", "user", "task", "execution", "doc", "session", "job"]]

    arguments: Optional[object]

    resource_id: Optional[str]

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputTextEditor20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["text_editor_20241022"]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInput(
    TypedDict, total=False
):
    name: Required[str]

    type: Required[
        Literal[
            "function",
            "integration",
            "system",
            "api_call",
            "computer_20241022",
            "text_editor_20241022",
            "bash_20241022",
        ]
    ]

    api_call: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputAPICall
    ]
    """API call definition"""

    bash_20241022: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputBash20241022
    ]

    computer_20241022: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputComputer20241022
    ]
    """Anthropic new tools"""

    description: Optional[str]

    function: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputFunction
    ]
    """Function definition"""

    integration: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputIntegration
    ]
    """Brave integration definition"""

    system: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputSystem
    ]
    """System definition"""

    text_editor_20241022: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInputTextEditor20241022
    ]


MainMainInputMapPromptStepInputToolsUnionMember1: TypeAlias = Union[
    MainMainInputMapPromptStepInputToolsUnionMember1ToolRef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenOpenAPIModelCreateToolRequestInput,
]


class MainMainInputMapPromptStepInput(TypedDict, total=False):
    prompt: Required[Union[Iterable[MainMainInputMapPromptStepInputPromptUnionMember0], str]]

    auto_run_tools: bool

    disable_cache: bool

    label: Optional[str]

    settings: Optional[ChatSettingsParam]

    tool_choice: Optional[MainMainInputMapPromptStepInputToolChoice]

    tools: Union[Literal["all"], Iterable[MainMainInputMapPromptStepInputToolsUnionMember1]]

    unwrap: bool


class MainMainInputMapGetStep(TypedDict, total=False):
    get: Required[str]

    label: Optional[str]


class MainMainInputMapSetStep(TypedDict, total=False):
    set: Required[Dict[str, str]]

    label: Optional[str]


class MainMainInputMapLogStep(TypedDict, total=False):
    log: Required[str]

    label: Optional[str]


class MainMainInputMapYieldStep(TypedDict, total=False):
    workflow: Required[str]

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]], Literal["_"]]

    label: Optional[str]


MainMainInputMap: TypeAlias = Union[
    MainMainInputMapEvaluateStep,
    MainMainInputMapToolCallStep,
    MainMainInputMapPromptStepInput,
    MainMainInputMapGetStep,
    MainMainInputMapSetStep,
    MainMainInputMapLogStep,
    MainMainInputMapYieldStep,
]


class MainMainInput(TypedDict, total=False):
    map: Required[MainMainInputMap]

    over: Required[str]

    initial: object

    label: Optional[str]

    parallelism: Optional[int]

    reduce: Optional[str]


Main: TypeAlias = Union[
    MainEvaluateStep,
    MainToolCallStep,
    MainPromptStepInput,
    MainGetStep,
    MainSetStep,
    MainLogStep,
    MainYieldStep,
    MainReturnStep,
    MainSleepStep,
    MainErrorWorkflowStep,
    MainWaitForInputStep,
    MainIfElseWorkflowStepInput,
    MainSwitchStepInput,
    MainForeachStepInput,
    MainParallelStepInput,
    MainMainInput,
]


class ToolAPICall(TypedDict, total=False):
    method: Required[Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]]

    url: Required[str]

    content: Optional[str]

    cookies: Optional[Dict[str, str]]

    data: Optional[object]

    follow_redirects: Optional[bool]

    headers: Optional[Dict[str, str]]

    json: Optional[object]

    params: Union[str, object, None]

    schema: Optional[object]

    timeout: Optional[int]


class ToolBash20241022(TypedDict, total=False):
    name: str

    type: Literal["bash_20241022"]


class ToolComputer20241022(TypedDict, total=False):
    display_height_px: int

    display_number: int

    display_width_px: int

    name: str

    type: Literal["computer_20241022"]


class ToolFunction(TypedDict, total=False):
    description: Optional[object]

    name: Optional[object]

    parameters: Optional[object]


class ToolIntegrationDummyIntegrationDef(TypedDict, total=False):
    arguments: Optional[object]

    method: Optional[str]

    provider: Literal["dummy"]

    setup: Optional[object]


class ToolIntegrationBraveIntegrationDefArguments(TypedDict, total=False):
    query: Required[str]


class ToolIntegrationBraveIntegrationDefSetup(TypedDict, total=False):
    api_key: Required[str]


class ToolIntegrationBraveIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationBraveIntegrationDefArguments]
    """Arguments for Brave Search"""

    method: Optional[str]

    provider: Literal["brave"]

    setup: Optional[ToolIntegrationBraveIntegrationDefSetup]
    """Integration definition for Brave Search"""


_ToolIntegrationEmailIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_ToolIntegrationEmailIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class ToolIntegrationEmailIntegrationDefArguments(
    _ToolIntegrationEmailIntegrationDefArgumentsReservedKeywords, total=False
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]


class ToolIntegrationEmailIntegrationDefSetup(TypedDict, total=False):
    host: Required[str]

    password: Required[str]

    port: Required[int]

    user: Required[str]


class ToolIntegrationEmailIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationEmailIntegrationDefArguments]
    """Arguments for Email sending"""

    method: Optional[str]

    provider: Literal["email"]

    setup: Optional[ToolIntegrationEmailIntegrationDefSetup]
    """Setup parameters for Email integration"""


class ToolIntegrationSpiderIntegrationDefArguments(TypedDict, total=False):
    url: Required[str]

    mode: Literal["scrape"]

    params: Optional[object]


class ToolIntegrationSpiderIntegrationDefSetup(TypedDict, total=False):
    spider_api_key: Required[str]


class ToolIntegrationSpiderIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationSpiderIntegrationDefArguments]
    """Arguments for Spider integration"""

    method: Optional[str]

    provider: Literal["spider"]

    setup: Optional[ToolIntegrationSpiderIntegrationDefSetup]
    """Setup parameters for Spider integration"""


class ToolIntegrationWikipediaIntegrationDefArguments(TypedDict, total=False):
    query: Required[str]

    load_max_docs: int


class ToolIntegrationWikipediaIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationWikipediaIntegrationDefArguments]
    """Arguments for Wikipedia Search"""

    method: Optional[str]

    provider: Literal["wikipedia"]

    setup: Optional[object]


class ToolIntegrationWeatherIntegrationDefArguments(TypedDict, total=False):
    location: Required[str]


class ToolIntegrationWeatherIntegrationDefSetup(TypedDict, total=False):
    openweathermap_api_key: Required[str]


class ToolIntegrationWeatherIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationWeatherIntegrationDefArguments]
    """Arguments for Weather"""

    method: Optional[str]

    provider: Literal["weather"]

    setup: Optional[ToolIntegrationWeatherIntegrationDefSetup]
    """Integration definition for Weather"""


class ToolIntegrationBrowserbaseContextIntegrationDefArguments(TypedDict, total=False):
    project_id: Required[Annotated[str, PropertyInfo(alias="projectId")]]


class ToolIntegrationBrowserbaseContextIntegrationDefSetup(TypedDict, total=False):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class ToolIntegrationBrowserbaseContextIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationBrowserbaseContextIntegrationDefArguments]

    method: Literal["create_context"]

    provider: Literal["browserbase"]

    setup: Optional[ToolIntegrationBrowserbaseContextIntegrationDefSetup]
    """The setup parameters for the browserbase integration"""


class ToolIntegrationBrowserbaseExtensionIntegrationDefArguments(TypedDict, total=False):
    repository_name: Required[Annotated[str, PropertyInfo(alias="repositoryName")]]

    ref: Optional[str]


class ToolIntegrationBrowserbaseExtensionIntegrationDefSetup(TypedDict, total=False):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class ToolIntegrationBrowserbaseExtensionIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationBrowserbaseExtensionIntegrationDefArguments]

    method: Optional[Literal["install_extension_from_github"]]

    provider: Literal["browserbase"]

    setup: Optional[ToolIntegrationBrowserbaseExtensionIntegrationDefSetup]
    """The setup parameters for the browserbase integration"""


class ToolIntegrationBrowserbaseListSessionsIntegrationDefArguments(TypedDict, total=False):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]]


class ToolIntegrationBrowserbaseListSessionsIntegrationDefSetup(TypedDict, total=False):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class ToolIntegrationBrowserbaseListSessionsIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationBrowserbaseListSessionsIntegrationDefArguments]

    method: Literal["list_sessions"]

    provider: Literal["browserbase"]

    setup: Optional[ToolIntegrationBrowserbaseListSessionsIntegrationDefSetup]
    """The setup parameters for the browserbase integration"""


class ToolIntegrationBrowserbaseCreateSessionIntegrationDefArguments(TypedDict, total=False):
    browser_settings: Annotated[object, PropertyInfo(alias="browserSettings")]

    extension_id: Annotated[Optional[str], PropertyInfo(alias="extensionId")]

    keep_alive: Annotated[bool, PropertyInfo(alias="keepAlive")]

    project_id: Annotated[Optional[str], PropertyInfo(alias="projectId")]

    proxies: Union[bool, Iterable[object]]

    timeout: int


class ToolIntegrationBrowserbaseCreateSessionIntegrationDefSetup(TypedDict, total=False):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class ToolIntegrationBrowserbaseCreateSessionIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationBrowserbaseCreateSessionIntegrationDefArguments]

    method: Literal["create_session"]

    provider: Literal["browserbase"]

    setup: Optional[ToolIntegrationBrowserbaseCreateSessionIntegrationDefSetup]
    """The setup parameters for the browserbase integration"""


class ToolIntegrationBrowserbaseGetSessionIntegrationDefArguments(TypedDict, total=False):
    id: Required[str]


class ToolIntegrationBrowserbaseGetSessionIntegrationDefSetup(TypedDict, total=False):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class ToolIntegrationBrowserbaseGetSessionIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationBrowserbaseGetSessionIntegrationDefArguments]

    method: Literal["get_session"]

    provider: Literal["browserbase"]

    setup: Optional[ToolIntegrationBrowserbaseGetSessionIntegrationDefSetup]
    """The setup parameters for the browserbase integration"""


class ToolIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(TypedDict, total=False):
    id: Required[str]

    status: Literal["REQUEST_RELEASE"]


class ToolIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(TypedDict, total=False):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class ToolIntegrationBrowserbaseCompleteSessionIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationBrowserbaseCompleteSessionIntegrationDefArguments]

    method: Literal["complete_session"]

    provider: Literal["browserbase"]

    setup: Optional[ToolIntegrationBrowserbaseCompleteSessionIntegrationDefSetup]
    """The setup parameters for the browserbase integration"""


class ToolIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(TypedDict, total=False):
    id: Required[str]


class ToolIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(TypedDict, total=False):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class ToolIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments]

    method: Literal["get_live_urls"]

    provider: Literal["browserbase"]

    setup: Optional[ToolIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup]
    """The setup parameters for the browserbase integration"""


class ToolIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments(TypedDict, total=False):
    id: Required[str]


class ToolIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup(TypedDict, total=False):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class ToolIntegrationBrowserbaseGetSessionConnectURLIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments]

    method: Literal["get_connect_url"]

    provider: Literal["browserbase"]

    setup: Optional[ToolIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup]
    """The setup parameters for the browserbase integration"""


class ToolIntegrationRemoteBrowserIntegrationDefSetup(TypedDict, total=False):
    connect_url: Optional[str]

    height: Optional[int]

    width: Optional[int]


class ToolIntegrationRemoteBrowserIntegrationDefArguments(TypedDict, total=False):
    action: Required[
        Literal[
            "key",
            "type",
            "mouse_move",
            "left_click",
            "left_click_drag",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
            "cursor_position",
            "navigate",
            "refresh",
        ]
    ]

    connect_url: Optional[str]

    coordinate: Optional[Iterable[object]]

    text: Optional[str]


class ToolIntegrationRemoteBrowserIntegrationDef(TypedDict, total=False):
    setup: Required[ToolIntegrationRemoteBrowserIntegrationDefSetup]
    """The setup parameters for the remote browser"""

    arguments: Optional[ToolIntegrationRemoteBrowserIntegrationDefArguments]
    """The arguments for the remote browser"""

    method: Literal["perform_action"]

    provider: Literal["remote_browser"]


ToolIntegration: TypeAlias = Union[
    ToolIntegrationDummyIntegrationDef,
    ToolIntegrationBraveIntegrationDef,
    ToolIntegrationEmailIntegrationDef,
    ToolIntegrationSpiderIntegrationDef,
    ToolIntegrationWikipediaIntegrationDef,
    ToolIntegrationWeatherIntegrationDef,
    ToolIntegrationBrowserbaseContextIntegrationDef,
    ToolIntegrationBrowserbaseExtensionIntegrationDef,
    ToolIntegrationBrowserbaseListSessionsIntegrationDef,
    ToolIntegrationBrowserbaseCreateSessionIntegrationDef,
    ToolIntegrationBrowserbaseGetSessionIntegrationDef,
    ToolIntegrationBrowserbaseCompleteSessionIntegrationDef,
    ToolIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    ToolIntegrationBrowserbaseGetSessionConnectURLIntegrationDef,
    ToolIntegrationRemoteBrowserIntegrationDef,
]


class ToolSystem(TypedDict, total=False):
    operation: Required[
        Literal[
            "create",
            "update",
            "patch",
            "create_or_update",
            "embed",
            "change_status",
            "search",
            "chat",
            "history",
            "delete",
            "get",
            "list",
        ]
    ]

    resource: Required[Literal["agent", "user", "task", "execution", "doc", "session", "job"]]

    arguments: Optional[object]

    resource_id: Optional[str]

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]]


class ToolTextEditor20241022(TypedDict, total=False):
    name: str

    type: Literal["text_editor_20241022"]


class Tool(TypedDict, total=False):
    name: Required[str]

    type: Required[
        Literal[
            "function",
            "integration",
            "system",
            "api_call",
            "computer_20241022",
            "text_editor_20241022",
            "bash_20241022",
        ]
    ]

    api_call: Optional[ToolAPICall]
    """API call definition"""

    bash_20241022: Optional[ToolBash20241022]

    computer_20241022: Optional[ToolComputer20241022]
    """Anthropic new tools"""

    description: Optional[str]

    function: Optional[ToolFunction]
    """Function definition"""

    integration: Optional[ToolIntegration]
    """Brave integration definition"""

    system: Optional[ToolSystem]
    """System definition"""

    text_editor_20241022: Optional[ToolTextEditor20241022]
